@@ -50,6 +50,11 @@ class Plot:
             self.point(**self.transform(x[i], y[i], i, self.series))
         self.series += 1
 
+    def plot_scatter_pairs(self, pairs):
+        for i, pair in enumerate(pairs):
+            self.point(**self.transform(pair[0], pair[1], i, self.series))
+        self.series += 1
+
     def plot_scatter_xs(self, xs, y):
         for x in xs: self.plot_scatter(x, y)
 
@@ -86,6 +91,7 @@ class Plot:
         if len(args) == 1:
             if   _is_dim(args[0], 1): plot_func = self.plot_list
             elif _is_dim(args[0], 2): plot_func = self.plot_lists
+            elif _type_r(args[0]) == _type_r([(0,)]): plot_func = self.plot_scatter_pairs
             elif type(args[0]) == dict: plot_func = self.plot_dict
             elif _type_r(args[0]) == _type_r([{}]): plot_func = self.plot_dicts
             elif callable(args[0]): plot_func = self.plot_f
